#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from pathlib import Path

from setuptools import setup

setup(
    name="balaboba",
    version="1.0.2",
    description="Module for interacting with Yandex Balaboba",
    long_description=(Path(__file__).parent / "README.md").read_text(),
    long_description_content_type="text/markdown",
    url="https://github.com/monosans/balaboba",
    author="monosans",
    author_email="hsyqixco@protonmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    packages=["balaboba"],
    python_requires=">=3.6",
    include_package_data=True,
    install_requires=["requests"],
)



# -*- coding: utf-8 -*-
from requests import Session


def _fetch(query: str, intro: int, session: Session) -> str:
    r = session.post(
        "https://yandex.ru/lab/api/yalm/text3",
        json={"query": query, "intro": intro, "filter": 1},
    ).json()
    return r["query"] + r["text"]


def balaboba(query: str, *, intro: int = 0, session: Session = None) -> str:
    """Отправка запроса Яндекс Балабобе.

    Args:
        query (str): Текст для Балабобы.
        intro (int, optional): Вариант стилизации.
            0 - Без стиля. По умолчанию.
            1 - Теории заговора.
            2 - ТВ-репортажи.
            3 - Тосты.
            4 - Пацанские цитаты.
            5 - Рекламные слоганы.
            6 - Короткие истории.
            7 - Подписи в Instagram.
            8 - Короче, Википедия.
            9 - Синопсисы фильмов.
            10 - Гороскоп.
            11 - Народные мудрости.
            12 - Балабоба x Garage.
        session (Session, optional): По умолчанию None.

    Returns:
        str: Ответ Балабобы.
    """
    if session:
        return _fetch(query, intro, session)
    with Session() as session:
        return _fetch(query, intro, session)
